<?php
namespace Ep\Google;

use Ep\WordPress\Settings\SettingsProviderInterface;
use Zend\Stdlib\ArrayUtils;

/**
 * Class ConfigProvider
 *
 * @package Ep\Google
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider implements SettingsProviderInterface
{
	public function __invoke()
	{
		$recaptchaSettings = $this->getDefaults()['ep_recaptcha'];

		if (function_exists('get_option')) {
			$recaptchaSettings = ArrayUtils::merge($recaptchaSettings, get_option('ep_recaptcha', []));
		}

		return [
			'dependencies' => $this->getDependencyConfig(),
			'recaptcha' => $recaptchaSettings,

			'http_clients' => [
				'recaptcha' => [
					'base_uri' => 'https://www.google.com',
				],
			],

			'validators' => [
				'aliases' => [
					'recaptcha' => Validator\ReCaptcha::class,
					'reCaptcha' => Validator\ReCaptcha::class,
					'ReCaptcha' => Validator\ReCaptcha::class,
				],

				'factories' => [
					Validator\ReCaptcha::class => Validator\ReCaptchaFactory::class,
				],
			],
		];
	}

	public function getDependencyConfig()
	{
		return [];
	}

	/**
	 * Vraća zadane postavke koje provider pruža.
	 *
	 * @return array
	 */
	public function getDefaults()
	{
		return [
			'ep_recaptcha' => [
				'enabled' => '0',
				'site_key' => '',
				'secret_key' => '',
			],
		];
	}

	/**
	 * Vraća forme za postavke.
	 *
	 * @return array
	 */
	public function getForms()
	{
		return [
			'ep_recaptcha' => 'settings-recaptcha',
		];
	}

	/**
	 * Vraća tabove u control panelu koje ovaj provider definira.
	 *
	 * @return array
	 */
	public function getTabs()
	{
		return [[
			'id' => 'general',
			'optionKeys' => [
				'ep_recaptcha',
			],
		]];
	}
}