<?php
namespace Ep\WooCommerce\Ajax;

use Ep\WordPress\Service\AbstractWordPressService;
use WC_Product_Variable;

/**
 * Ajax handler za dodavanje u košaricu.
 *
 * @package Ep\WooCommerce\Ajax
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class AddToCart extends AbstractWordPressService
{
	const ACTION = 'ep_add_to_cart';

	public function attach(): void
	{
		add_action(sprintf('wp_ajax_%s', static::ACTION), [$this, 'action']);
		add_action(sprintf('wp_ajax_nopriv_%s', static::ACTION), [$this, 'action']);
	}

	public function action()
	{
		ob_start();

		$cart = WC()->cart;

		switch ($_POST['type']) {
			case 'grouped':
				$mainProductId = absint($_POST['groupedProductId']);
				break;
			case 'variable':
				$mainProductId = absint($_POST['variableProductId']);
				break;
			case 'simple':
			default:
				$mainProductId = null;
		}

		if (isset($_POST['products']) && is_array($_POST['products'])) {
			foreach ($_POST['products'] as $productId => $quantity) {
				$productId = apply_filters('woocommerce_add_to_cart_product_id', absint($productId));
				$quantity = wc_stock_amount($quantity);
				$isValid = apply_filters('woocommerce_add_to_cart_validation', true, $productId, $quantity);
				$productStatus = get_post_status($productId);

				if ($isValid && 'publish' === $productStatus && false !== $cart->add_to_cart($productId, $quantity)) {
					wc_add_to_cart_message([$productId => $quantity], true);
					do_action('woocommerce_ajax_added_to_cart', $productId);
				}

				if ('grouped' !== $_POST['type']) {
					$mainProductId = $productId;
				}
			}
		} else if (isset($_POST['attributes']) && is_array($_POST['attributes'])) {
			/** @var WC_Product_Variable $product */
			$product = wc_get_product($mainProductId);
			$variationId = null;

			foreach ($product->get_available_variations() as $variation) {
				$match = true;

				foreach ($_POST['attributes'] as $name => $value) {
					if (!isset($variation['attributes'][$name]) || $variation['attributes'][$name] !== $value) {
						$match = false;
					}
				}

				if ($match) {
					$variationId = $variation['variation_id'];
					break;
				}
			}

			$cart->add_to_cart($mainProductId, wc_stock_amount($_POST['quantity']), $variationId, $_POST['attributes']);
		}

		ob_start();
		woocommerce_mini_cart();
		$miniCart = ob_get_clean();

		global $post, $product;

		if (!$post) {
			$GLOBALS['post'] = get_post($mainProductId);
		}

		if (!$product) {
			$GLOBALS['product'] = wc_get_product($mainProductId);
		}

		ob_start();
		do_action(sprintf('woocommerce_%s_add_to_cart', $_POST['type']), $mainProductId);
		$addToCartForm = ob_get_clean();

		$data = array(
			'fragments' => apply_filters('woocommerce_add_to_cart_fragments', [
				'div.widget_shopping_cart_content' => '<div class="widget_shopping_cart_content">' . $miniCart . '</div>',
			]),
			'replace' => $addToCartForm,
			'cart_hash' => apply_filters('woocommerce_add_to_cart_hash',
				$cart->get_cart_for_session() ? md5(json_encode($cart->get_cart_for_session())) : '',
				$cart->get_cart_for_session()
			),
		);

		wp_send_json($data);
	}
}