<?php
namespace Ep\WordPress\Form;

use WP_Post;
use Zend\Form\Element\Select;

/**
 * Omogućava odabir WordPress posta.
 *
 * @package Ep\WordPress\Form
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class PostSelect extends Select
{
	/** @var string */
	protected $indentationString = '–';

	/**
	 * Vraća opcije.
	 *
	 * @return array
	 */
	public function getValueOptions()
	{
		if (empty($this->valueOptions)) {
			if (!function_exists('get_posts')) {
				throw new \RuntimeException('Ovaj element ne može funkcionirati bez WordPressa.');
			}

			$postType = $this->getOption('post_type') ?: 'post';
			$this->addValueOptions($postType);
		}

		return $this->valueOptions;
	}

	/**
	 * Dodaje djecu datog roditelja u popis opcija.
	 *
	 * @param string $postType
	 * @param int $postParent
	 * @param int $depth
	 */
	protected function addValueOptions(string $postType = 'post', int $postParent = 0, int $depth = 0)
	{
		/** @var WP_Post[] $posts */
		$posts = get_posts([
			'post_type' => $postType,
			'post_status' => 'publish',
			'post_parent' => $postParent,
			'order' => 'ASC',
			'orderby' => 'post_title',
			'posts_per_page' => -1,
		]);

		foreach ($posts as $post) {
			$this->valueOptions[$post->ID] = sprintf(
				'%s %s',
				str_repeat($this->indentationString, $depth),
				$post->post_title
			);

			$this->addValueOptions($postType, $post->ID, $depth + 1);
		}
	}
}